/******************************************************************************
 *** Swedish i18l Strings                                                   ***
 ******************************************************************************/
msgid(LANG_NATIVE_NAME)
msgstr("Svenska")

msgid(LANG_ENGLISH_NAME)
msgstr("Swedish")


/******************************************************************************
 *** Splash Message & Change Log                                            ***
 ******************************************************************************/

// msgid(SPLASH_TITLE)
// Don't translate this.

//msgid(SPLASH_TEXT)
// Don't translate this.

// msgid(CHANGE_LOG_TITLE)
// Don't translate this.

// msgid(CHANGE_LOG_TEXT)
// Don't translate this.

/******************************************************************************
 *** MISC & UNSORTED                                                        ***
 ******************************************************************************/

msgid(REQ_SENT)
msgstr("Vänskapsbegäran skickad. Din vän kommer att visas som online efter att din begäran har accepterats.")

msgid(REQ_INVALID_ID)
msgstr("Fel: Ogiltigt Tox-ID")

msgid(REQ_EMPTY_ID)
msgstr("Fel: Inget Tox-ID angivet")

msgid(REQ_LONG_MSG)
msgstr("Fel: Meddelandet är för långt")

msgid(REQ_NO_MSG)
msgstr("Fel: Tomt meddelande")

msgid(REQ_SELF_ID)
msgstr("Fel: Du har angett ditt egna Tox-ID")

msgid(REQ_ALREADY_FRIENDS)
msgstr("Fel: Tox-ID är redan i din vänlista")

msgid(REQ_UNKNOWN)
msgstr("Fel: Okänt")

msgid(REQ_BAD_CHECKSUM)
msgstr("Fel: Ogiltigt Tox-ID (inkorrekt checksumma)")

msgid(REQ_BAD_NOSPAM)
msgstr("Fel: Ogiltigt Tox-ID (inkorrekt nospamvärde)")

msgid(REQ_NO_MEMORY)
msgstr("Fel: Inget minne")

msgid(SEND_FILE)
msgstr("Skicka fil")

msgid(SAVE_FILE)
msgstr("Spara fil")

msgid(WHERE_TO_SAVE_FILE_PROMPT)
msgstr("Vart vill du spara \"%.*s\"?")

msgid(WHERE_TO_SAVE_FILE)
msgstr("Vart vill du spara filen?")

msgid(SEND_FILE_PROMPT)
msgstr("Markera en eller flera filer att skicka.")

msgid(SCREEN_CAPTURE_PROMPT)
msgstr("Markera området på skärmen du vill skicka.")


/******************************************************************************
 *** File Transfer Strings                                                  ***
 ******************************************************************************/
msgid(TRANSFER_NEW)
msgstr("Ny filöverföring")

msgid(TRANSFER_STARTED)
msgstr("Filöverföring påbörjad")

msgid(TRANSFER___)
msgstr("...")

msgid(TRANSFER_PAUSED)
msgstr("Filöverföring pausad")

msgid(TRANSFER_BROKEN)
msgstr("Filöverföring trasig")

msgid(TRANSFER_CANCELLED)
msgstr("Filöverföring avbruten")

msgid(TRANSFER_COMPLETE)
msgstr("Filöverföring färdig")


/******************************************************************************
 *** Keyboard and Mouse Cursor Strings                                      ***
 ******************************************************************************/
msgid(CURSOR_CLICK_LEFT)
msgstr("Vänsterklick")

msgid(CURSOR_CLICK_RIGHT)
msgstr("Högerklick")


/******************************************************************************
 *** Audio / Video Call Strings                                             ***
 ******************************************************************************/
msgid(CALL_START_AUDIO)
msgstr("Starta samtal")

msgid(CALL_START_VIDEO)
msgstr("Starta videosamtal")

msgid(CALL_DECLINE)
msgstr("Neka samtal")

msgid(CALL_CANCELLED)
msgstr("Samtal avbrutet")

msgid(CALL_INVITED)
msgstr("Inbjuden till samtal")

msgid(CALL_RINGING)
msgstr("Samtal ringer")

msgid(CALL_STARTED)
msgstr("Samtal påbörjat")

msgid(CALL_FRIEND_HAD_ENDED_CALL)
msgstr(" har avslutat samtalet!")

msgid(CALL_VIDEO_SHOW_INLINE)
msgstr("Visa video inline")


/******************************************************************************
 *** Friend & Friend Settings Strings                                       ***
 ******************************************************************************/
msgid(FRIEND_ALIAS)
msgstr("Sätt vännens alias")

msgid(FRIEND_PUBLIC_KEY)
msgstr("Vännens publika nyckel")

msgid(FRIEND_AUTOACCEPT)
msgstr("Acceptera inkommande filöverföringar utan bekräftelse")

msgid(FRIEND_EXPORT_CHATLOG)
msgstr("Exportera chattlogg i klartext")


/******************************************************************************
 *** Group Strings                                                          ***
 ******************************************************************************/
msgid(GROUPCHAT_JOIN_AUDIO)
msgstr("Gå med i ljudchatt")

msgid(GROUP_CREATE_TEXT)
msgstr("Skapa en textgruppchatt")

msgid(GROUP_CREATE_VOICE)
msgstr("Skapa en gruppchatt med ljud")

msgid(CREATEGROUPCHAT)
msgstr("Skapa gruppchatt")

msgid(REMOVE_GROUP)
msgstr("Ta bort grupp")

msgid(LEAVE_GROUP)
msgstr("Lämna grupp")


/******************************************************************************
 *** Group Settings                                                         ***
 ******************************************************************************/
msgid(GROUPCHAT_SETTINGS)
msgstr("Inställningar för Gruppchatt")

msgid(GROUP_NOTIFICATIONS)
msgstr("Gruppnotifieringar")

msgid(GROUP_NOTIFICATIONS_ON)
msgstr("På")

msgid(GROUP_NOTIFICATIONS_MENTION)
msgstr("Nämnd")

msgid(GROUP_NOTIFICATIONS_OFF)
msgstr("Av")

msgid(GROUP_TOPIC)
msgstr("Ställ in gruppens tema")

/******************************************************************************
 *** Settings / Profile Strings                                             ***
 ******************************************************************************/
msgid(PROFILE_BUTTON)
msgstr("Profil")

msgid(DEVICES_BUTTON)
msgstr("Apparater")

msgid(USER_INTERFACE_BUTTON)
msgstr("Gränssnitt")

msgid(AUDIO_VIDEO_BUTTON)
msgstr("Ljud & video")

msgid(ADVANCED_BUTTON)
msgstr("Avancerat")

msgid(NOTIFICATIONS_BUTTON)
msgstr("Notifieringar")

msgid(PROFILE_SETTINGS)
msgstr("Profilinställningar")

msgid(PROFILE_PW_WARNING)
msgstr("VARNING: µTox kommer automatiskt börja kryptera med detta lösenord.")

msgid(PROFILE_PW_NO_RECOVER)
msgstr("Det går ej att återställa ett borttappat lösenord.")



/***        Profile                                                         ***/

/***        Devices                                                         ***/
msgid(DEVICES_ADD_NEW)
msgstr("Lägg till apparat till nätverket")

msgid(DEVICES_NUMBER)
msgstr("Antal länkade apparater")
/***        Network                                                         ***/

/***        User Interface                                                  ***/

/***        Audio/Video                                                     ***/



/******************************************************************************
 *** UNSORTED STRINGS                                                       ***
 *** TODO:                                                                  ***
 *** FIXME:                                                                 ***
 ******************************************************************************/
msgid(ADDFRIENDS)
msgstr("Lägg till vän")

msgid(TOXID)
msgstr("Tox-ID")

msgid(MESSAGE)
msgstr("Meddelande")

msgid(FILTER_ONLINE)
msgstr("Online")

msgid(FILTER_ALL)
msgstr("Alla")

msgid(FILTER_CONTACT_TOGGLE)
msgstr("Växla filtrering av frånkopplade kontakter.")

msgid(ADD)
msgstr("Lägg till")

msgid(FRIENDREQUEST)
msgstr("Vänskapsinbjudan")

msgid(USERSETTINGS)
msgstr("Användarinställning")

msgid(FRIEND_SETTINGS)
msgstr("Väninställningar")

msgid(NAME)
msgstr("Namn")

msgid(STATUSMESSAGE)
msgstr("Statusmeddelande")

msgid(PREVIEW)
msgstr("Förhandsvisning")

msgid(AUDIOINPUTDEVICE)
msgstr("Ljudingång")

msgid(AUDIOFILTERING)
msgstr("Ljudfiltrering")

msgid(AUDIOOUTPUTDEVICE)
msgstr("Ljudutgång")

msgid(VIDEOINPUTDEVICE)
msgstr("Bildingång")

msgid(PUSH_TO_TALK)
msgstr("LCtrl för att tala")

msgid(STATUS)
msgstr("Status")

msgid(STATUS_ONLINE)
msgstr("Online")

msgid(STATUS_AWAY)
msgstr("Borta")

msgid(STATUS_BUSY)
msgstr("Upptagen")

msgid(SETTINGS_UI_MINI_ROSTER)
msgstr("Kompakt kontaktlista")

msgid(SETTINGS_UI_AUTO_HIDE_SIDEBAR)
msgstr("Dölj sidofältet automatiskt")

msgid(NOT_CONNECTED)
msgstr("Ej ansluten")

msgid(NOT_CONNECTED_SETTINGS)
msgstr("Modifiera nätverksinställningarna")

msgid(OTHERSETTINGS)
msgstr("Andra inställningar")

msgid(UI)
msgstr("UI")

msgid(USER_INTERFACE)
msgstr("Gränssnitt")

msgid(UTOX_SETTINGS)
msgstr("Inställningar för uTox")

msgid(NETWORK_SETTINGS)
msgstr("Nätverksinställningar")

msgid(PROFILE_PASSWORD)
msgstr("Profillösenord")

msgid(LOCK_UTOX)
msgstr("Kopplar ifrån Tox och låser profilen.")

msgid(SHOW_UI_PASSWORD)
msgstr("Visa lösenordsfältet")

msgid(SHOW_UI_PASSWORD_TOOLTIP)
msgstr("Klicka för att visa lösenordsfältet. Ändringar som görs här tar effekt direkt!")

msgid(HIDE_UI_PASSWORD)
msgstr("Dölj lösenordsfältet")

msgid(HIDE_UI_PASSWORD_TOOLTIP)
msgstr("Klicka för att dölja lösenordsfältet.")

msgid(LOCK)
msgstr("Lås")

msgid(AUDIO_VIDEO)
msgstr("Ljud/Video")

msgid(DPI)
msgstr("DPI")

msgid(SAVELOCATION)
msgstr("Sparplats")

msgid(LANGUAGE)
msgstr("Språk")

msgid(NETWORK)
msgstr("Nätverk")

msgid(IPV6)
msgstr("IPv6:")

msgid(UDP)
msgstr("UDP:")

msgid(PROXY)
msgstr("Proxy (SOCKS 5)")

msgid(PROXY_FORCE)
msgstr("Tvinga uTox att alltid använda proxyn")

msgid(WARNING)
msgstr("Om du ändrar Network/Proxy så kommer du att tillfälligt tappa din anslutning till Toxnätverket")

msgid(SAVE_CHAT_HISTORY)
msgstr("Spara chatthistorik")

msgid(AUDIONOTIFICATIONS)
msgstr("Aktivera ljudnotifikationer (ringsignal)")

msgid(RINGTONE)
msgstr("Rington")

msgid(IS_TYPING)
msgstr("skriver...")

msgid(CLOSE_TO_TRAY)
msgstr("Stäng till aktivitetsfältet")

msgid(START_IN_TRAY)
msgstr("Starta i aktivitetsfältet")

msgid(COPY)
msgstr("Kopiera")

msgid(COPYWITHOUTNAMES)
msgstr("Kopiera (utan namn)")

msgid(COPY_WITH_NAMES)
msgstr("Kopiera (inklusive namn)")

msgid(CUT)
msgstr("Klipp ut")

msgid(PASTE)
msgstr("Klistra in")

msgid(DELETE)
msgstr("Ta bort")

msgid(SELECTALL)
msgstr("Välj alla")

msgid(REMOVE)
msgstr("Ta bort")

msgid(REMOVE_FRIEND)
msgstr("Ta bort vän")

msgid(LEAVE)
msgstr("Lämna")

msgid(CTOPIC)
msgstr("Ändra tema")

msgid(ACCEPT)
msgstr("Tillåt")

msgid(IGNORE)
msgstr("Ignorera")

msgid(SET_ALIAS)
msgstr("Sätt alias")

msgid(ALIAS)
msgstr("Alias")

msgid(SENDMESSAGE)
msgstr("Skicka meddelande")

msgid(SENDSCREENSHOT)
msgstr("Skicka skärmdump")

msgid(CLICKTOSAVE)
msgstr("Klicka för att spara")

msgid(CLICKTOOPEN)
msgstr("Klicka för att öppna")

msgid(CANCELLED)
msgstr("Avbruten")

msgid(DPI_060)
msgstr("Anpassad DPI 60%")

msgid(DPI_070)
msgstr("Anpassad DPI 70%")

msgid(DPI_080)
msgstr("Anpassad DPI 80%")

msgid(DPI_090)
msgstr("Anpassad DPI 90%")

msgid(DPI_100)
msgstr("Anpassad DPI 100%")

msgid(DPI_110)
msgstr("Anpassad DPI 110%")

msgid(DPI_120)
msgstr("Anpassad DPI 120%")

msgid(DPI_130)
msgstr("Anpassad DPI 130%")

msgid(DPI_140)
msgstr("Anpassad DPI 140%")

msgid(DPI_150)
msgstr("Anpassad DPI 150%")

msgid(DPI_160)
msgstr("Anpassad DPI 160%")

msgid(DPI_170)
msgstr("Anpassad DPI 170%")

msgid(DPI_180)
msgstr("Anpassad DPI 180%")

msgid(DPI_190)
msgstr("Anpassad DPI 190%")

msgid(DPI_200)
msgstr("Anpassad DPI 200%")

msgid(DPI_210)
msgstr("Anpassad DPI 210%")

msgid(DPI_220)
msgstr("Anpassad DPI 220%")

msgid(DPI_230)
msgstr("Anpassad DPI 230%")

msgid(DPI_240)
msgstr("Anpassad DPI 240%")

msgid(DPI_250)
msgstr("Anpassad DPI 250%")

msgid(DPI_260)
msgstr("Anpassad DPI 260%")

msgid(DPI_270)
msgstr("Anpassad DPI 270%")

msgid(DPI_280)
msgstr("Anpassad DPI 280%")

msgid(DPI_290)
msgstr("Anpassad DPI 290%")

msgid(DPI_300)
msgstr("Anpassad DPI 300%")

msgid(DPI_TINY)
msgstr("Liten (50%)")

msgid(DPI_NORMAL)
msgstr("Normal (100%)")

msgid(DPI_BIG)
msgstr("Stor (150%)")

msgid(DPI_LARGE)
msgstr("Större (200%)")

msgid(DPI_HUGE)
msgstr("Enorm (250%)")

msgid(PROXY_DISABLED)
msgstr("Inaktiverad")

msgid(PROXY_FALLBACK)
msgstr("Fallback")

msgid(PROXY_ALWAYS_USE)
msgstr("Använd alltid")

msgid(NO)
msgstr("Nej")

msgid(YES)
msgstr("Ja")

msgid(OFF)
msgstr("Av")

msgid(ON)
msgstr("På")

msgid(SHOW)
msgstr("Visa")

msgid(HIDE)
msgstr("Dölj")

msgid(VIDEO_IN_NONE)
msgstr("Inget")

msgid(VIDEO_IN_DESKTOP)
msgstr("Skrivbord")

msgid(AUDIO_IN_DEFAULT_LOOPBACK)
msgstr("Standard loopback")

// msgid(AUDIO_IN_ANDROID) Not needed
// msgstr("OpenSL Input")

msgid(DEFAULT_FRIEND_REQUEST_MESSAGE)
msgstr("Var god och acceptera min vänskapsbegäran.")

msgid(CONTACT_SEARCH_ADD_HINT)
msgstr("Sök/Lägg till vänner")

msgid(PROXY_EDIT_HINT_IP)
msgstr("IP")

msgid(PROXY_EDIT_HINT_PORT)
msgstr("Port")

msgid(WINDOW_TITLE_VIDEO_PREVIEW)
msgstr("Videoförhandsgranskning")

msgid(MUTE)
msgstr("Tysta")

msgid(UNMUTE)
msgstr("Avtysta")

msgid(SELECT_AVATAR_TITLE)
msgstr("Välj Avatar")

msgid(AVATAR_TOO_LARGE_MAX_SIZE_IS)
msgstr("Avatar för stor. Maxstorlek: ")

msgid(CANT_FIND_FILE_OR_EMPTY)
msgstr("Kan ej hitta den markerade filen eller så är den tom.")

msgid(CLEAR_HISTORY)
msgstr("Rensa historik")

msgid(AUTO_STARTUP)
msgstr("Starta sammtidigt som datorn")

msgid(THEME)
msgstr("Tema")

msgid(THEME_DEFAULT)
msgstr("Standard")

msgid(THEME_LIGHT)
msgstr("Ljust tema")

msgid(THEME_DARK)
msgstr("Mörkt tema")

msgid(THEME_HIGHCONTRAST)
msgstr("Högkontrast")

msgid(THEME_CUSTOM)
msgstr("Anpassat (se dokumentation)")

// msgid(THEME_ZENBURN) Not needed
// msgstr("Zenburn")

// msgid(THEME_SOLARIZED_LIGHT) Not needed
// msgstr("Solarized-light")

// msgid(THEME_SOLARIZED_DARK) Not needed
// msgstr("Solarized-dark")

msgid(SEND_TYPING_NOTIFICATIONS)
msgstr("Skicka skrivnotifieringar")

msgid(STATUS_NOTIFICATIONS)
msgstr("Statusnotifieringar")

msgid(RANDOMIZE_NOSPAM)
msgstr("Slumpmässig Nospam")

// msgid(NOSPAM) Not needed
// msgstr("Nospam")

msgid(REVERT_NOSPAM)
msgstr("Återställ Nospam")

msgid(NOSPAM_WARNING)
msgstr("Ändrar du ditt nospam slutar ditt gamla Tox-ID att fungera. uTox uppdaterar inte ditt ID på namnservrar.")

msgid(BLOCK_FRIEND_REQUESTS)
msgstr("Blockera inkommande vänskapsbegäran")

msgid(SHOW_NOSPAM)
msgstr("Visa Nospam-inställningar")

msgid(HIDE_NOSPAM)
msgstr("Dölj Nospam-inställningar")

msgid(DELETE_FRIEND)
msgstr("Ta bort vän")

msgid(DELETE_MESSAGE)
msgstr("Är du säker på att du vill ta bort ")

msgid(KEEP)
msgstr("Behåll")
